# 5. Animating a Molecular Morph
# Making a Movie with the Morph Output
# Code 2: Making a movie from the methyltransferase morph trajectory

# This script loads the morph from generic_morph.pml.  It then loads
# the holo structure to obtain the ligands and any solvent nearby the
# binding pocket.  Lastly, this movie inserts and shows the ligands
# in the molecular morph movie.
#
# This script will output an MPEG file:
#     morph_movie.mpeg

/import os
/cmd.cd(os.path.dirname(__script__))

# Load the multi-state pdb file
load morph_out.pdb

# load the holo structure
load ../pdbs/2zvj.pdb, tmp

# create two objects, one called ligand and the other called waters.  These objects are 
# created FROM state 1 of the tmp object just loaded and will be inserted into state 30
# of the molecular morph movie.
create ligand, tmp and organic, 1, 30

# do likewise for the waters nearby the binding pocket
create waters, tmp and (solvent within 5 of organic), 1, 30

# remove this object, we only needed the ligands and waters
delete tmp

# Use the mset command to make a movie. This starts in state 1 for 30 frames (1x30),
# then transitions up to state 30 (1-30). Next, it stops at state 30 for 30 frames
# (30x30). Then, it goes back to state one, taking another 30 frames to do so (30-1).
mset 1x30 1-30 30x30 30-1

# setup the scene.
orient ligand
show_as sticks, ligand
zoom center, 12
turn x, 90

# This is the command line version of File->Save Movie As->MPEG.
cmd.movie.produce("morph_movie.mpeg", quiet=0)
